==> ejc-proequipmentcorp-impl-3.0.0-20230804.080255-454-sources.jar: com/ejianc/business/proequipmentcorppur/purchase/service/IChangePurchaseContractService.java <==
package com.ejianc.business.proequipmentcorppur.purchase.service;

import com.ejianc.business.proequipmentcorppur.purchase.vo.ChangePurchaseContractVO;
import com.ejianc.business.proequipmentcorppur.purchase.vo.PurchaseContractVO;
import com.ejianc.business.targetcost.vo.ParamsCheckVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;
import com.ejianc.business.proequipmentcorppur.purchase.bean.ChangePurchaseContractEntity;

import java.util.List;
import java.util.Map;

/**
 * 设备采购合同-变更表
 * 
 * @author generator
 * 
 */
public interface IChangePurchaseContractService extends IBaseService<ChangePurchaseContractEntity> {

    ChangePurchaseContractVO queryDetailRecord(Long id);

    Boolean editChangeFlag(Long id);

    ChangePurchaseContractVO addConvertByConId(Long contractId, Long changeId);

    ChangePurchaseContractVO insertOrUpdate(ChangePurchaseContractVO saveorUpdateVO, Boolean isControl);

    ChangePurchaseContractVO queryDetail(Long id);

    CommonResponse<String> deleteById(Long changeBillId);

    Map<String, Object> queryChangeCompare(Long id);

    ChangePurchaseContractVO queryChangeRecord(Long contractId, Long changeId);

    CommonResponse<String> effectiveSaveWriteContract(Long changeBillId, String billTypeCode, Boolean commitState,Boolean filingFlag);

    ParamsCheckVO targetCostCtrl(ChangePurchaseContractVO changeContractVO);

    ParamsCheckVO viewTargetCostCtrlInfo(Long id);

    ParamsCheckVO checkParams(ChangePurchaseContractVO vo, ParamsCheckVO paramsCheckVO2);
    /**
     * 单据管控-累计变更金额大于合同金额
     * @return
     */
    List<ParamsCheckVO> checkParamsMny(ChangePurchaseContractVO vo);
    /*施工合同 控 变更合同
     *        @param 变更合同vo vo

     * */
    List<ParamsCheckVO> checkParamsConstruction(ChangePurchaseContractVO vo);

    void asyncWatermarkById(Long billId);
}

==> ejc-proequipmentcorp-impl-3.0.0-20250923.034303-514-sources.jar: com/ejianc/business/proequipmentcorppur/purchase/service/IChangePurchaseContractService.java <==
package com.ejianc.business.proequipmentcorppur.purchase.service;

import com.ejianc.business.proequipmentcorppur.purchase.vo.ChangePurchaseContractVO;
import com.ejianc.business.proequipmentcorppur.purchase.vo.PurchaseContractVO;
import com.ejianc.business.targetcost.vo.ParamsCheckVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;
import com.ejianc.business.proequipmentcorppur.purchase.bean.ChangePurchaseContractEntity;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 设备采购合同-变更表
 * 
 * @author generator
 * 
 */
public interface IChangePurchaseContractService extends IBaseService<ChangePurchaseContractEntity> {

    ChangePurchaseContractVO queryDetailRecord(Long id);

    Boolean editChangeFlag(Long id);

    ChangePurchaseContractVO addConvertByConId(Long contractId, Long changeId);

    ChangePurchaseContractVO insertOrUpdate(ChangePurchaseContractVO saveorUpdateVO, Boolean isControl);

    ChangePurchaseContractVO queryDetail(Long id);

    CommonResponse<String> deleteById(Long changeBillId);

    Map<String, Object> queryChangeCompare(Long id);

    ChangePurchaseContractVO queryChangeRecord(Long contractId, Long changeId);

    CommonResponse<String> effectiveSaveWriteContract(Long changeBillId, String billTypeCode, Boolean commitState,Boolean filingFlag);

    ParamsCheckVO targetCostCtrl(ChangePurchaseContractVO changeContractVO);

    ParamsCheckVO viewTargetCostCtrlInfo(Long id);

    ParamsCheckVO checkParams(ChangePurchaseContractVO vo, ParamsCheckVO paramsCheckVO2);
    /**
     * 单据管控-累计变更金额大于合同金额
     * @return
     */
    List<ParamsCheckVO> checkParamsMny(ChangePurchaseContractVO vo);
    /*施工合同 控 变更合同
     *        @param 变更合同vo vo

     * */
    List<ParamsCheckVO> checkParamsConstruction(ChangePurchaseContractVO vo);

    void asyncWatermarkById(Long billId);

    List<ParamsCheckVO> historyPriceCtrlContractPrice(ChangePurchaseContractVO changeVO);
}
